package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$"`0`````````````#`!0````!```>(````#0``0%T``"````T`"``
M"0`H`!T`'`````8````T````-````#0```$@```!(`````0````$`````P``
M`50```%4```!5`````T````-````!`````$````!``````````````````"5
M````E0`````%``$```````$``/R<``'\G``!_)P```.T```3S`````8``0``
M`````@``_=0``?W4``']U````2````$@````!@````0````$```!9````60`
M``%D````1````$0````$````!&1TY5```(U(``"-2```C4@```$<```!'```
M``0````$9'3E40``````````````````````````````!@```!!D=.52``#\
MG``!_)P``?R<```#9````V0````$`````2]L:6(O;&0N<V\N,0`````````$
M````%`````-'3E4`SHAE31D0;QB6+.W^'U9^\5/(CBP````$````$`````%'
M3E4```````````,````$`````````,$```!G``````````P```!<`````P``
M`````````````````"```````````````#````!B````'@```!L```!5````
M8P```````````````````&0````````````````````5````````````````
M````````````````````````````````````````````````````````````
M````````&`````````!0`````````$T`````````)P```#,`````````````
M`"P`````````20``````````````*````!D`````````````````````````
M.``````````T````3@`````````O````````````````````5@``````````
M`````````$<`````````(0```&8`````````'P``````````````````````
M``!>````!``````````.`````````#\`````````!P````````!`````00``
M```````````````````````-`````````"T````2````90``````````````
M.@```$L```````````````````!#````2@```%$````Y````````````````
M````$````"8``````````````$(```!4`````````!,`````````6````#<`
M```]```````````````/````7P```$0`````````60```#L`````````````
M`#8````K`````````#4`````````10```$8````Q````*0```"H```!@````
M````````````````+@````````!;````,@````````````````````(````+
M````3P```",````D````5P`````````(``````````````!=````/@``````
M````````4P``````````````2``````````=````````````````````````
M`%H````````````````````)````)0``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````!0``````````````%```````````````````
M`````````````````````````````````"(`````````````````````````
M```````````````````````````````````````````````````````````:
M`````````````````````````#P```````````````````!A````````````
M````````%@``````````````$0```%(`````````"@``````````````````
M``````!,`````````````````````````````````````````!P`````````
M`````````````````````!<`````````````````````````!@`````````N
M````3`````@````(!!`0`(`$0"4$```HA`"&H````8`(!"@+11*@.`@``(H`
M``!,`````````$X```!0`````````%$`````````4@```%,`````````5```
M``````!5````5@````````!8``````````````!9`````````%H`````````
M``````````!;````7`````````!=````7@````````!?``````````````!@
M`````````&$```!B````````````````````8P```&0`````````90``````
M````MIO%+GR:?VL+ESH,S"6,%8?7^D-)^^"C[-5%0]-P!XD<6''9GN/-VYN<
MJ7XM1][/+#_EPWS49-7MVV(SGN(4#0H"I^$?W\5OUD,):P[D_R%\DN.[P.-+
MK6^+`;-0GAIK`<9'XV;,KV9@;*'[`````````````````````````````!OT
M``````,```P```$-```````````2````````@```````````$@```````4P`
M`````````!(```````%;```````````2```````!=0``````````(```````
M`%\``````````!$```````.E```````````2```````!(```````````$0``
M`````-0``````````!(```````+$```````````2````````\0``````````
M$@```````%@``````````!(```````'(```````````2```````"*@``````
M````$@```````*\``````````!(```````)K```````````2```````"OP``
M````````$@```````SP``````````!(```````$&```````````2```````#
M'0``````````$0```````+4``````````!(```````)Z```````````2````
M```!JP``````````$0```````+P``````````!(```````).```````````2
M```````"`0``````````$@```````!```````````"(```````*?````````
M```2````````,0``````````$@```````-P``````````!(```````+)````
M```````2````````S```````````$@```````M4``````````!(```````&X
M```````````2```````!9@``````````(````````10``````````!(`````
M``#C```````````2```````"W```````````$@```````(<``````````!(`
M```````?```````````2```````"$P``````````$@```````(X`````````
M`!(```````*J```````````2```````"'P``````````$@```````1D`````
M`````!(```````$G```````````2```````"_```````````$@```````2T`
M`````````!(```````#%```````````2```````##P``````````$@``````
M`>0``````````!(```````#X```````````2```````"0P``````````$@``
M`````3X``````````!(```````+K```````````2````````<0``````````
M$@```````H@``````````!(```````#J```````````2````````8```````
M````(0```````=8``````````!(```````'P```````````2```````"7```
M````````$@```````CH``````````!(```````%3```````````2````````
MG```````````$@```````9$``````````"````````!I```````````2````
M````80``````````$0```````$,``````````!(```````,H```````````2
M````````30``````````$@```````6```````````!(```````"F````````
M```2````````>```````````$@```````X(``#5H````.!(```T````L```<
M0````>`2```-```#]``"`!``````(```&```!(P``#RD````B!(```T```/G
M```]+````/P2```-```$-```..@```&@$@``#0```[H``@!0`````!```!D`
M``0E``(`3`````01```9```$2P`"`%``````$```&@``!!4``$C`````>!(`
M``T```.3```Z^````$@2```-```#V@``/WP```9($@``#0``!%<``#0$````
M4!(```T```25``!%Q````OP2```-```#^```'B`````T$@``#0```W(``$DX
M````#!(```T```/_```TK````+P2```-```#K@``/!@```",$@``#0```_(`
M`@`0`````!```!@```1?```UH````<P2```-```$+P`"$&@`````$```&@``
M``$``$_L````!!$```\```1^```ZB````'`2```-```$00``/B@```%4$@``
M#0```\$``#=L````,!(```T```/.```WG````4P2```-```$;```.T````#8
M$@``#0!?24]?<W1D:6Y?=7-E9`!?7V-X85]F:6YA;&EZ90!?7VQI8F-?<W1A
M<G1?;6%I;@!?7W)E9VES=&5R7V%T9F]R:P!?7WAS=&%T-C0`7U]L>'-T870V
M-`!M96UC<'D`7U]E;G9I<F]N`'-T<FYC;7``86-C97-S`&]P96YD:7(`<W1R
M8VUP`'-T<FQE;@!?7W-P<FEN=&9?8VAK`')E861D:7(V-`!C;&]S961I<@!R
M;61I<@!U;FQI;FL`<F5A9&QI;FL`;65M8VAR`')E86QL;V,`;65M;6]V90!G
M971P:60`<W1R8VAR`'-T<G1O:P!S=')D=7``7U]S=')N8W!Y7V-H:P!G971U
M:60`<W1R<W1R`&5X:70`;65M<V5T`'-T9&5R<@!M:V1I<@!?7V5R<FYO7VQO
M8V%T:6]N`%]?9G!R:6YT9E]C:&L`;W!E;C8T`&QS965K-C0`<F5A9`!C;&]S
M90!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`
M7TE435]R96=I<W1E<E1-0VQO;F5486)L90!03%]D;U]U;F1U;7``4&5R;%]G
M=E]F971C:'!V`%!E<FQ?879?<VAI9G0`4&5R;%]A=E]F971C:`!097)L7VUG
M7W-E=`!097)L7V%T9F]R:U]L;V-K`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?
M9V5T7W-V`%!E<FQ?;F5W6%,`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<G5N`'!E
M<FQ?<&%R<V4`4&5R;%]S=E]S971P=@!097)L7W-V7W-E='!V;@!P97)L7V-O
M;G-T<G5C=`!P97)L7V1E<W1R=6-T`%!E<FQ?8W)O86M?;65M;W)Y7W=R87``
M<&5R;%]A;&QO8P!097)L7V-R;V%K7VYO8V]N=&5X=`!P97)L7V9R964`4&5R
M;%]S869E<WES;6%L;&]C`%!E<FQ?<WES7VEN:70S`%!E<FQ?;F5W6%-?9FQA
M9W,`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<WES7W1E<FT`4$Q?=&AR7VME
M>0!P=&AR96%D7V=E='-P96-I9FEC`%]?<W1A8VM?8VAK7V9A:6P`;&EB<&5R
M;"YS;P!L:6)P=&AR96%D+G-O+C``;&EB8RYS;RXV`%]?;&EB8U]C<W5?9FEN
M:0!P87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED
M`'!A<E]C;&5A;G5P`%]E9&%T80!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`
M<&%R7VUK=&UP9&ER`'-H85]U<&1A=&4`7U]D871A7W-T87)T`'!A<E]C=7)R
M96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`%]E;F0`
M<&%R7VEN:71?96YV`'-H85]F:6YA;`!?7V)S<U]S=&%R=`!X<U]I;FET`'!A
M<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`'-H
M85]I;FET`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C``1TQ)0D-?
M,BXR`$=,24)#7S(N,RXT`$=,24)#7S(N,RXR`$=,24)#7S(N,2XS`$=,24)#
M7S(N-`!'3$E"0U\R+C$`+W5S<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/4D4`
M`````````@`"``,``@````(``@`"``(``@`"``(```````(```````0``@``
M``(```````(```````4````&``(````"``(```````(``@````(``@````0`
M``````(``@````(``@``````!P````0````"`````@`"`````````````P`(
M`````@`"``@`"0`(``(``@`"``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0```U@````0````(`UI
M:1`````)```$JP```````0`'```#:````!``````#6EI$@````@```2U````
M$`EI&70````'```$OP```!`):1ER````!@``!,L````0"6D?<P````4```37
M````$`UI:10````$```$XP```!`-:6D1`````P``!.T````0#6EI$`````(`
M``2K```````!_)P````6```?@``!_*`````6```?$``!_*0````6``(`3``!
M_*P````6``(`3``!_+0````6``(`4``!_+P````6``(`%``!_,0````6``!/
M\0`!_,@````6``!/\``!_,P````6``!/\P`!_-`````6``!/^0`!_-@````6
M``(`5``!_-P````6``"-'``!_.0````6``!0"``!_.@````6``!2LP`!_.P`
M```6``!%Q``!_/`````6``!0)``!_/0````6``!0!``!_/@````6``!0.0`!
M_/P````6``!010`!_0`````6``!03@`!_00````6``!06P`!_0@````6``!0
M70`!_0P````6``!17@`!_1`````6``!07P`!_10````6``!0:``!_1@````6
M``!0<``!_1P````6``!0>0`!_2`````6``!0@``!_20````6``!0D``!_2@`
M```6``!0G``!_2P````6``!0I@`!_3`````6``!0L``!_30````6``!0N@`!
M_3@````6``!0RP`!_3P````6``!0W0`!_4`````6``!0Z``!_40````6``!0
M^``!_4@````6``!1"0`!_4P````6``!1%``!_5`````6``(`&``!_50````6
M``!1%@`!_5@````6``!1)@`!_6@````6``!1*P`!_6P````6``(`3``!_7``
M```6``!1+@`!_70````6```T5``!_7@````6``!1,0`!_7P````6``!15P`!
M_8`````6``!17``!_80````6``!190`!_8P````6``!1H``!_9`````6``!1
M(0`!_90````6``!1\P`!_9@````6``!1^``!_9P````6``!1_0`!_:`````6
M``!2#``!_:0````6``!2&@`!_:@````6``!2*P`!_:P````6``!2,``!_;``
M```6``!2,@`!_;0````6``!24``!_;@````6``!2-P`!_;P````6``!23``!
M_<`````6``!24@`!_<0````6``!2<P`!_<@````6``'\H``!_<P````6``'\
MG``!_=`````6``(`%``"```````6``'^^``"``0````6```<0``"``@````6
M``!(P``"``P````6``!).``"`!0````6``(`%``"`!P````6``!1.``"`"``
M```6``!/\0`"`"@````6``!0W0`"`"P````6``!0U@`"`#`````6``!1/0`"
M`#0````6``!0\P`"`#@````6``!110`"`$`````6``!120`"`$0````6``!1
M3@`"`$P````6``!2M``!_*@```8!```````!_+```$,!```````!_+@``!P!
M```````!_,```$4!```````!_-0``!4!```````!_.````\!```````!_5P`
M`#`!```````!_6```#X!```````!_60``!@!```````!_8@```D!```````!
M_O0``"04```````!_P0```(5```````!_P@```,5```````!_PP```05````
M```!_Q````45```````!_Q0```@5```````!_Q@```H5```````!_QP```L5
M```````!_R````P5```````!_R0```T5```````!_R@```X5```````!_RP`
M`!`5```````!_S```!$5```````!_S0``!(5```````!_S@``!,5```````!
M_SP``!05```````!_T```!85```````!_T0``!<5```````!_T@``!D5````
M```!_TP``!H5```````!_U```!L5```````!_U0``!P5```````!_U@``!T5
M```````!_UP``!X5```````!_V```!\5```````!_V0``"`5```````!_V@`
M`"$5```````!_VP``"(5```````!_W```",5```````!_W0``"05```````!
M_W@``"45```````!_WP``"85```````!_X```"<5```````!_X0``"@5````
M```!_X@``"D5```````!_XP``"H5```````!_Y```"L5```````!_Y0``"P5
M```````!_Y@``"T5```````!_YP``"X5```````!_Z```"\5```````!_Z0`
M`#$5```````!_Z@``#(5```````!_ZP``#,5```````!_[```#05```````!
M_[0``#45```````!_[@``#85```````!_[P``#<5```````!_\```#@5````
M```!_\0``#D5```````!_\@``#H5```````!_\P``#L5```````!_]```#T5
M```````!_]0``#\5```````!_]@``$`5```````!_]P``$$5```````!_^``
M`$(5```````!_^0``$05```````!_^@``$85```````!_^P``$<5```````!
M__```$@5```````!__0``$D5```````!__@``$H5```````!__P``$L5````
M`)0A__!\"`*FD`$`%)/!``A"GP`%?\@"IC_>``([WN+P@![__"^```!!O@`(
M2``P,8`!`!1\"`.F@\$`"#@A`!!.@``@``````````"4(?_0?`@"ID*?``6_
M@0`@?\@"IC_>``*080`<.&$`'#O>8'20@0`8.($`&)"A`!0XH0`4D`$`-$@`
M,`F`OH"<@'Z`H'RD*WA(`"R]@3Z`I(/^@!B#OH`4BXD``"P<``!`@@`L2``O
M/2P#``"0?Q`$0*(`##A@``%(`"^I2``NA8!]``!(`#%MFX,((8!]``!(`#%A
MB2,$=F$I``*9(P1V@'T``$@`,4V)(P1V82D``9DC!'8]($``@&$`'#AC``5\
M`TA`0:``"$@`,)E48Q`Z2``O`8#A`!@Y```!@*$`''QJ&WA\9AMXD'\0"($G
M```L!0``D2,``($^@*B1(P`$@3Z`K($I``"1(P`(@3Z`L)4J``PY(``$D3\0
M#'RI*WA!H0`(.2```2P)``$Y*?__0*(`G%2I$#HY0```@)Z`M#DI``R`?Q`$
M..```'U&22XXI0`#2``OS7Q]&WE`H@`0@'\0!$@`,#U\?1MX@'\0!$@`+>&`
M?H!D3,8Q@D@`$,TL`P``0*(`,($_$!`L"0``0*(`%(!^@#Q,QC&"2``0K9!_
M$!"`?Q`0+`,``$&"``A(`!XI@'\0!$@`+5E(`"\U.6$`,'^CZWA(`"Q@5000
M.CD(``%\AR`NE(H`!$O__TQ\*0MX5"$`-D*?``5]J`*F.````)0A__!\"`.F
MD`$``#_-``(]#0`".][@S(6HX=1(`"Y0E"'_\'P(`J9"GP`%D\$`"'_(`J8_
MW@`"D`$`%#O>7D2`?H``@3Z`"'P)&`!!@@`8@3Z`!"P)``!!@@`,?2D#IDZ`
M!"&``0`4@\$`"#@A`!!\"`.F3H``()0A__!\"`*F0I\`!9/!``A_R`*F/]X`
M`I`!`!0[WEWL@'Z``(">@`A\@R!0?(06<'R$#G!\A`&508(`&($^@`PL"0``
M08(`#'TI`Z9.@`0A@`$`%(/!``@X(0`0?`@#IDZ``""4(?_P?`@"ID*?``63
MP0`(?\@"IC_>``*0`0`4.]Y=B)/A``R#_H`0B3\``"P)``!`@@`H@3Z`%"P)
M``!!@@`0@3Z`&(!I``!(`"QY2__^^3D@``&9/P``@`$`%(/!``B#X0`,."$`
M$'P(`Z9.@``@2___+)0A_G!\"`*F0I\`!3B#`!PXH`!`ON$!;'_(`J9\?QMX
MD`$!E#_>``(X80`<.]Y=,($BC_B1(0%<.2```$@`*U$Y(`!`.4$`&'TI`Z:!
M*@`X@.H`)($*``Q]*3IX?2E">(4*``1]*4)X52D(/I$J`$!"`/_<@2$`'(&?
M``"!?P`0@'\`"#TI6H*`GP`,.2EYF56**#Z`'P`$?2E:%%6;\#Z!`0`@?2E2
M%'QJ(GB`H0`H?4H`.%0'\#Y]2B)X/0A:@GS\VGA]*5(4?&HZ>#D(>9E]2F`X
M?0@B%#RE6H)]2AIX?YQ(.#BE>9E]2D(452@H/GRE.A1]2D(4@0$`)%4I\#Y_
MG#IX@.$`+']]2GA_O5`X/0A:@G^]VG@Y"'F9/.=:@G^]*A1]"!H4..=YF7^<
M0A152"@^54KP/G^<0A1])E)X?.?:%%>(*#Y\QN`X5YSP/G^]0A1\QDIX?47B
M>%>H*#Y\QCH4?*7H.'S&0A2!`0`P5[WP/GRE4GB#80`X?X?J>'SG,#@]"%J"
M?.?B>#D(>9D_>UJ"?2A*%($!`#0[>WF9?25*%%3%*#Y4QO`^?*DJ%($A`#Q_
MF^(4/0A:@H-A`$`Y"'F9?4A2%'^H,G@]*5J"?4=2%'T(*#A4IR@^5*7P/GSJ
M.A1]".IX?,HJ>'^(XA0Y*7F95.@H/GU*.#A_J>H4?1Q"%'U*,GA4Y_`^?ZKJ
M%%4**#Z#@0!$?5U2%(.A`$A\J3IX/WM:@GTI0#A5"/`^.WMYF7TI*GA\]T)X
M?-LR%#^<6H(_O5J"?,DR%'[W4#A522@^.YQYF55*\#X[O7F9?29*%'[W.GA]
M&%)X?+PJ%'S].A2#H0!,?+<J%'\82#A5-R@^?N6Z%%4I\#Y_&$)X@,$`4'SX
M.A1]64IX5O@H/C^]6H)_.;@X?P?"%%;W\#Z`X0!4.[UYF7\Y4GA].KIX?1U"
M%#S&6H)_6L`X?1E"%#C&>9E7&2@^5QCP/G\HRA1_6DIX?492%'[[PG@\YUJ"
M?5I2%($!`%A7.B@^?WO(.#CG>9E_2M(4?WNZ>'TG2A17.?`^?3M*%%=;*#Y_
M!LIX?2G:%#T(6H*#80!<?,;0.#D(>9E76O`^?NBZ%'S&PGA5/"@^?R?2>'S&
MNA0_>UJ"?,;B%'SG2#B#@0!@.WMYF7SGRGB`H0!D?WO"%%3**#Z#H0!H?.?:
M%%4[\#X_G%J"?TC:>#N<>9E\YU(4?0@P.'^<RA0\I5J"?0C2>%3I*#XXI7F9
M?0CB%%3<\#Y\I=(4?VKB>'T(2A14^O`^?4HX.%4)*#Z`P0!L?4K:>#^]6H)]
M2BH4.[UYF8"A`'!]2DH4?XG2>'^]VA1]*4`X51OP/CS&;MI]*>)X54<H/G](
MVGA]*>H4.,;KH7T(4GA]*3H4?,;B%#SE;MI57/`^?,9"%%4H*#Y\QD(4?V7B
M>($!`'0XY^NA?*5*>%3**#Y\Y](453WP/GSG*A0]"&[:?XGJ>'SG4A2!00!X
M.0CKH7TI,GA]"-H45,;P/GT(2A14Z2@^@*$`?#U*;MI]"$H4?ZDR>#E*ZZ%]
M*3IX5.?P/GU*XA1]2DH450DH/GU*2A0])6[:?,4Z>#DIZZ%\I4)X50CP/GTI
MZA1]*2H4544H/GTI*A2`H0"`/*5NVCBEZZ%\Q3(4?.5">'RE4GA52O`^?,8J
M%%4E*#Y\QBH4@*$`A#RE;MHXI>NA?.4Z%'T%4GA\I4IX52GP/GSG*A14Q2@^
M?.<J%("A`(B#@0"\@T$`X#RE;MHXI>NA/YR/''T%0A1]14IX.YR\W'RE,GA4
MQO`^/UJ/''T(*A14Y2@^.UJ\W'T(*A2`H0",/*5NVCBEZZ%]15(4?24R>'RE
M.GA4Y_`^?4HJ%%4%*#Y]2BH4@*$`D#RE;MHXI>NA?25*%'S%.GA\I4)X50CP
M/GTI*A1512@^?2DJ%("A`)0\I6[:.*7KH7S%,A1\Y4)X?*52>%5*\#Y\QBH4
M524H/GS&*A2`H0"8/*5NVCBEZZ%\Y3H4?052>'RE2GA5*?`^?.<J%%3%*#Y\
MYRH4@*$`G#RE;MHXI>NA?05"%'U%2GA\I3)X5,;P/GT(*A14Y2@^?0@J%("A
M`*`\I6[:.*7KH7U%4A1])3)X?*4Z>%3G\#Y]2BH4504H/GU**A2`H0"D/*5N
MVCBEZZ%])4H4?,4Z>'RE0GA5"/`^?2DJ%%5%*#Y]*2H4@*$`J#RE;MHXI>NA
M?,4R%'SE0GA\I5)X54KP/GS&*A15)2@^?,8J%("A`*P\I6[:.*7KH7SE.A1]
M!5)X?*5*>%4I\#Y\YRH45,4H/GSG*A2`H0"P/*5NVCBEZZ%]!4(4?45*>'RE
M,GA4QO`^?0@J%%3E*#Y]""H4@*$`M#RE;MHXI>NA?452%'TE,GA\I3IX5.?P
M/GU**A15!2@^?4HJ%("A`+@\I6[:.*7KH7TE2A1\Q3IX?-PR%'RE0GA5"/`^
M@X$`Q'S]0WA]*2H4544H/GTI*A1_O5`X?.5`.'^]*WA52O`^524H/GS=,A2#
MH0#`?1M3>'S&*A1_>T@X?050.%4I\#Y_>RMX/YR/'#^]CQQ]14@X.YR\W#N]
MO-Q]'$(4?/TZ%'U=2WA\^SH4?[TP.%3;*#Y4QO`^?V?:%'^]*WA]/#-X5V4H
M/GT=0A1_G-@X5WOP/GT(*A1\Q]MX?24P.(.A`,A_G"MX?.=`.'S%V#A\YRMX
M@*$`S#^]CQP[O;S<?5U2%#RECQR#H0#8?5Q2%#BEO-Q5'"@^?XKB%'TE2A15
M"/`^?2=*%%>'*#Y_94`X?2DZ%']G0W@_O8\<?.?@.%><\#X[O;S<?.<K>("A
M`-!]"N`X/*6/'#BEO-Q\Q3(4?07C>'T=0A1\I4@X?,<R%%4G*#Y\I5-X@4$`
MU%4I\#Y\QCH4?X=(.#U*CQPY2KS<?VK:%'^*2WA]2C`X?V7:%%3%*#Y]2CMX
M5,?P/H#!`-Q\NRH4?3T[>'T*0A1_O2@X5*HH/E2E\#X\QH\<?0A2%'TJ.#@X
MQKS<?[U3>'SJ*#A_AN(4?.8K>(-A`.1\QD`X?YWB%%4=*#Y\QE-X50KP/G^\
MZA1\N5-X?*A0.'TZ2A1_.>@X/WN/''TF2A1_.4-X@0$`Z%>F*#X[>[S<5[WP
M/GS),A1]6NMX?/LZ%'U<Z#@]"(\<?/DZ%']:,#@Y"+S<5-DH/E3&\#Y\J"H4
M@0$`['\GRA1_6N-X?[LS>%<\*#Y\NBH4?WO(.%<Y\#X]"(\<?X7B%'S)R#@Y
M"+S<?Z4P.%>:\#Y]2%(4?,C+>'][*WA]".`X?5M2%%>;*#Y]"$MX@2$`\']J
MVA2!00#X@X$`_#TICQR`H0$`.2F\W#U*CQQ_J>H4?RG0.#E*O-Q_J.H45V@H
M/C^<CQQ]'4(4?SW3>'\JRA1_O=@X5WOP/CN<O-Q_O4MX@2$`]'^<TA0\I8\<
M.*6\W#TICQQ\I=H4.2F\W'S),A1_2=MX?-TR%%4=*#Y]*4`X?Z;J%%4(\#Y_
M1M@X?V=#>'TI,WA_:D`X5Z8H/GSGZ#A]*<H4?2DR%'SG4WA7O?`^52HH/GSG
MXA1]!N@X?.=2%'T*ZWA]2D@X5/OP/GU*,WA4YB@^?4HJ%'U*,A15)O`^?ZDS
M>'^E,#A56O`^?2DX.'TI*WB`H0$$/*6/'#BEO-Q]!4(4?,7;>'T)0A1522@^
M?*50.'T(2A1\R=@X?VK2>'RE2WB!(0$(?4I">%4<\#X]*8\<.2F\W'^IZA15
M"2@^?*7J%'RE2A2!(0$,5+WP/G^(ZG@]*<IC.2G!UGTI,A2`P0$0?2E2%%2J
M*#Y]*5(4/.;*8W]&XGA5*B@^..?!UGS&*GA]"$IX?.?:%%4I\#Y\YS(4?Z9*
M>'SG4A2!00$4?,8Z>#U*RF,Y2L'6?4K2%'U*0A14Z"@^5.?P/GU*0A2!`0$8
M/0C*8SD(P=9]".(4?0@R%%5&*#Y]"#(4@,$!'#RFRF-])CIX.*7!UGS&4GA5
M2O`^?*7J%'RE,A15!B@^?*4R%(#!`2`\QLIC.,;!UGTF2A1\YE)X?,9">%4(
M\#Y]*3(45*8H/GTI,A2`P0$D/,;*8SC&P=9\QCH4?4=">'SG*GA4I?`^?,8Z
M%%4G*#Y\QCH4@.$!*#SGRF,XY\'6?4=2%'T'*GA\YTIX52GP/GU*.A14QR@^
M?4HZ%(#A`2P\Y\IC..?!UGT'0A1\ITIX?.<R>%3&\#Y]"#H454<H/GT(.A2`
MX0$P/.?*8SCGP=9\IRH4?2<R>'SG4GA52O`^?*4Z%%4'*#Y\I3H4@.$!-#SG
MRF,XY\'6?2=*%'S'4GA\YT)X50CP/GTI.A14IR@^?2DZ%(#A`3@\Y\IC..?!
MUGS',A1]1T)X?.<J>%2E\#Y\QCH452<H/GS&.A2`X0$\/.?*8SCGP=9\YU(4
M?0HJ>'U*2GA5*?`^?.=2%%3**#Y\YU(4@4$!0#U*RF,Y2L'6?0I"%'RJ2GA]
M2C)X5,;P/GT(4A14ZB@^?0A2%(%!`40]2LIC.4K!UGRJ*A1]*C)X?4HZ>%3G
M\#Y\I5(450HH/GRE4A2!00%(/4K*8SE*P=9]*DH4?,HZ>'U*0GA5"/`^?2E2
M%%2J*#Y]*5(4@4$!3#U*RF,Y2L'6?,HR%'SJ0GA]2BIX5*7P/GS&4A15*B@^
M?,92%(%!`5`]2LIC.4K!UGU*.A1]!RIX?.=*>%4I\#Y]2CH45,<H/GU*.A2`
MX0%4/.?*8SCGP=9]!T(4?*=*>'SG,GA4QO`^?0@Z%%5'*#Y\A#(4?0@Z%(#A
M`5B0GP`,/.?*8SCGP=9]AV(4?2<R>'TK2A1\YU)X?8PJ%%5*\#Y]C#H450<H
M/GQJ&A1]C#H4?0!"%)!_``B1GP``D1\`!)$_`!"!(0%<@4*/^'TI4GDY0```
M0:(`"$@`'%4Y80&02``<E)0A_]!\"`*F0I\`!;\A`!1_R`*F?'L;>3_>``*0
M`0`T.Z```#O>3O!!@@`@@3Z``#N@``!\F2-X?W_;>(.)```L'```0*(`'#EA
M`#!_H^MX2``<2"@)`#U!@@`4._\``8D_```L"0``0(+_['_[^%!_FN-X@[H`
M`"P=``!!HO_,?^7[>']DVWA_H^MX2``?P2P#``!`@@`H?3WXKBP)`#U`H@`<
M?YS04#O_``%_G!9P?[WZ%).9``!+__^0.UH`!$O__[24(?_@?`@"II`!`"0X
M@0`8@2*/^)$A`!PY(```3,8Q@DO__QV!(0`<@4*/^'TI4GDY0```0:(`"$@`
M&TV``0`D."$`('P(`Z9.@``@E"'_T'P(`J9"GP`%OZ$`)'_(`J9\?QMXD`$`
M-#_>``([H0`8.]Y-X($BC_B1(0`<.2```'^DZWA_X_MX3,8Q@DO__K$L`P``
M0*(`'($A`!R!0H_X?2E2>3E```!!H@`T2``:V8$A`!A5*1`Z.4G__($^@`"!
M*0``?2E2%(%)``@L"@``E4D`!$""__1+__^H.6$`,$@`&P24(?]P?`@"ID*?
M``6_P0"(?\@"ICB!`!"0`0"4/]X``GQ_&W@[WDU(@2*/^)$A`'PY(```2``:
M*2P#``!`@@!,@2$`(%4I!"8H"4``08(`$&TJ__\L"J``0((`&#B```)_X_MX
M2``=P7QC`#148]E^@2$`?(%"C_A]*5)Y.4```$&B`!!(`!H=.&```$O__^0Y
M80"02``:<)0A_V!\"`*F0I\`!;]!`(A_R`*F?'T;>9`!`*0_W@`".]Y,L($B
MC_B1(0!\.2```$&"`"")/0``+`D``$&"`!1(`!XM.T$`$'Q[&WE`H@"\@2$`
M?(%"C_A]*5)Y.4```$&B`-1(`!FE@)Z`!#O_`!-_X_MX2``:*2P#``!!@@",
M@)Z`"'_C^WA(`!H5+`,``$&B`'A_H^MX2``;]7Q\&WA_X_MX2``;Z7Q\&A0X
M8P`"2``;?8#>@`Q_Z/MX?'P;>'^GZW@XH/__.(```4S&,8)(`!OM?T33>'^#
MXWA(`!BE+`/__W^#XWA!@@!$@2$`(%4I!"8L"4``0*(`-$O__P5_@^-X2``9
MZ7]CVWA(`!SQ?'\;>4""_U1_8]MX2``=07^CZWA(`!H)2___*$@`&E%+___0
M.6$`H$@`&224(>_`?`@"ID*?``4XH`__OT$0*'_(`J9\?1MX/]X``I`!$$0[
M80`<.]Y+='R<(WA_9-MX@'Z`$($BC_B1(1`<.2```$@`&AV#7H`4?'\;>4"!
M`'`Y/___.4$0('U*2A2)2N_\+`H``$""`!`L"0``08(`4'T_2WA_Y?MX.(``
M+W]CVWA(`!M=+`,``$&"`#2`>@``2``<77_F^WA_9=MX?Z3K>$@`&^V!(1`<
M@4*/^'TI4GDY0```0:(`($@`&!&`>@``2``<+7^%XWA_I.MX2``9H4O__]0Y
M81!`2``81)0A_[!\"`*F0I\`!;[A`"Q_R`*F?'\;>)`!`%0_W@`"?)TC>#O>
M2I2!(H_XD2$`'#D@``"))```+`D`/4"B``@[I``!?Z/K>$@`&BDX@0`8?'P;
M>'_C^WA,QC&"2__[27Q[&WE!@@!`2``:"7P<&$!!H0"4.2```'U=2*XL"@``
M?5M)KCDI``%`@O_P@2$`'(%"C_A]*5)Y.4```$&B`4!(`!=-@SZ``#M```""
M^0``5TD0.GTW2"XL"0``0*(`Y($^@!@[>@`"5WL0.H%)```L"@``08(`U']D
MVWA^X[MX2``9(2P#``"0>0``0:+_H($Y``!_:=H4.2```)$[__R300`8?^G[
M>(E)```L"@``08(`#"@*`#U`H@"\@UZ``'T_2%`X?``"?&-*%(-A`!B#.@``
M2``8W2P#``!7>Q`Z?'G9+D&B_TB!(0`8.____X%:``!5*1`Z?2I(+HU?``%]
M*$MX.2D``2P*``"92?__08(`#"@*`#U`@O_D.4``/9E(```Y0```?1U0KBP(
M``!]"5&N.4H``4""__!+__[P.UH``4O__PPY0``!?V/;>)%)``!(`!A=?'@;
M>4&B_M`XN__X?N2[>$@`%OF3&0``2___(#DI``%+__\P.6$`4$@`%E24(?_@
M?`@"ID*?``63P0`8?\@"IC_>``*0`0`D.]Y(L($^@!2`:0``2``:!8#>@!R`
MOH`@@)Z`)$@`&*6``0`D@\$`&#@A`"!\"`.F3H``()0A_^!\"`*F0I\`!;_!
M`!A_R`*F/]X``I`!`"0[WDA@@_Z`%(!_``!(`!FU2___A8!_``!(`!FI@/Z`
M*#D```"`OH`L@)Z`,'SF.WA(`!CA.6$`($@`%<B4(=_0?`@"ID*?``6_@2`@
M?\@"ICOA$!B0`2`T/]X``CN!`!0[WD@(@2*/^)$A(!PY(```2``7(8$>@#2`
MWH`X?&<;>#B@$`$X@``!?^/[>$S&,8)(`!?!?^/[>#B@$`!_A.-X.^```$@`
M%HU\?1MY08``*#A]``%(`!<-?'\;>4&"`!A_I>MX?X3C>$@`%=DY(```?3_I
MKH$A(!R!0H_X?2E2>3E```!!H@`(2``4M3EA(#!_X_MX2``5!)0A_^!\"`*F
M0I\`!9/!`!A_R`*F/]X``I`!`"0[WD=,2___)8`!`"2#P0`8."$`('P(`Z9.
M@``@E"'O4'P(`J9"GP`%?8``)K[!$(A_R`*F?'T;>#_>``*0`1"T?)\C>#O>
M1Q21@1"$@'Z`/($BC_B1(1!\.2```$S&,8)+__BE.(``+WQZ&WA_H^MX2``6
M?2P#``!!@@`L@'Z`0'^DZWA,QC&"2__\%8$A$'R!0H_X?2E2>3E```!!H@$X
M2``3Z7^CZW@ZP```+AH``$@`%EV#/H!$.P```'Q\&WA_X_MX.V$`?#N<``$Z
MX0`08M:``'\DRWA(`!=5?'\;>"P?``!!HO^8B3\``"P)``!`@@`(@_Z`!$&2
M`!Q_Y/MX?T/3>$@`%!E_),MX+`,``$&"`+A_X_MX2``5]3E?__]]*ABN+`D`
M+T&B`(Q\?!H4+`,/_T&A_TB!'H!(?ZGK>'_G^WB`WH!,.*`0`#B```%_8]MX
M3,8Q@D@`%>5^Y+MX?V/;>$@`$ITL`P``0((`5($A`"!5*00F?`FP`$"B`$0X
M@``!?V/;>$@`%H4L`P``0*(`,(!^@$!_9-MX3,8Q@DO_^OU_8]MX2``3U7Q]
M&WA+__[<.&/__W\?&:Y+__]D?R3+>#A@``!(`!9E?'\;>$O__Q"!@1"$.6$0
ML'^CZWA]@($@2``2Z)0A__!\:1MXB4D``"P*``!`H@`,."$`$$Z``"`H"@`O
M.2D``4""_^1](TMX2___W)0A_^!\"`*F0I\`!;_!`!A_R`*F?'\;>3_>``*0
M`0`D.]Y%&$&"`!")/P``+`D``$"B`!2`?H`$2``3+3EA`"!(`!*42``4L3DC
M__]\:0.F?'\:%#AC__]\OTH4?!\80$&!``PL'___0*(`##D@``%]*0.F0D``
MO(DE```L"0`O0:(`H'P?*$!]/RA0.2D``7TI`Z9`H0`,.2```7TI`Z9"0`"0
MB24``#E%__\L"0`O0*(`>#E%__]]/RA0?!]00$&!``PL'___0*(`"#D@``$L
M"0`!.*7__SDI__]!@@`0B44``"P*`"]!@O_H?+\H4#A@```Y)0`"*`D0`$&A
M_T"!/H`8.,`0`#BE``%_Y/MX.2D`!'TC2WA(`!2=2___(#BE__]+__]0?453
M>$O__W1\'RA`0*+_@(D_```L"0`O0:+^](!^@$A+__[PE"'_H'P(`J9"GP`%
M.*``(K]A`$Q_R`*F.&$`&#_>``*0`0!D.]Y#S(">@!R!(H_XD2$`/#D@```X
MA``*2``1[8!^@%!,QC&"2__UI8!^@%1,QC&"2__UF8!^@%A,QC&"2__UC8!^
M@%Q,QC&"2__U@8.^@&!_H^MX3,8Q@DO_]7&`?H!D3,8Q@DO_]66#GH`\?X/C
M>$S&,8)+__55@_Z`:'_C^WA,QC&"2__U18-^@&Q_8]MX3,8Q@DO_]36`?H!P
M3,8Q@DO_]2F`?H!`3,8Q@DO_]1V`?H!T3,8Q@DO_],5\9!MY08(`$']CVWA,
MQC&"2__X28!^@'A,QC&"2__TI7QD&WE!@@`0@'Z`?$S&,8)+__@I@'Z`@$S&
M,8)+__2%?&0;>4&"`#A_@^-X3,8Q@DO_^`F`GH",?Z/K>$S&,8)+__?Y@2$`
M/(%"C_A]*5)Y.4```$&B`$1(``_-@'Z`A$S&,8)+__0]?&0;>4&"``Q_X_MX
M2___N(">@(@XH``*.&$`*4@`$Z4L`P``0(+_J#B!`#-+___<.6$`8$@`#^"4
M(?_@?`@"ID*?``6_P0`8?\@"IC_>``*0`0`D.]Y"+(/^@)"!/P``+`G__T"B
M`#B`?H!H3,8Q@DO_\\DY0```+`,``$&"`!R)(P``+`D``$&"`!!I*0`P,4G_
M_WU*21"17P``@'\``#EA`"!(``]\E"'_X'P(`J9"GP`%D\$`&'_(`J8_W@`"
MD`$`)#O>0;Q(`!!92``/M2P#``!!@@`(@&,``(`!`"2#P0`8."$`('P(`Z9.
M@``@E"'_T'P(`J9"GP`%OV$`''_(`J9\?QMX/]X``I`!`#0[WD%T@WZ`E']C
MVWA,QC&"2__S&7_D^WA\?1MY08(`$(D]```L"0``0((`,(`!`#1_8]MX@X$`
M((-A`!R#H0`D?`@#IH/!`"B#X0`L."$`,$S&,8)+__9L2``.V2P#``!`H@!0
M?^/[>$@`$,E\?!MX?Z/K>$@`$+U\?!H4.&,``D@`$%&!'H!$.(```8#>@$Q\
M?!MX?ZGK>'_G^W@XH/__3,8Q@D@`$+U_A.-X2___@#EA`#!(``Y0E"'_X'P(
M`J9"GP`%OZ$`%'_(`J9\?QMX/]X``I`!`"0[WD"<2__[84O_^RU\?1MX2__^
M02P#``!!@@!,+!\``$&"`$2)/P``+`D``$&"`#B`GH"8?Z/K>$@`#B%\'1@`
M0*(`)(`!`"1_X_MX@Z$`%(/!`!B#X0`<?`@#IC@A`"!+__-L.6$`($@`#<R4
M(?_@?`@"ID*?``4X8`!@D\$`&'_(`J8_W@`"D`$`)#O>0!!(``]I/4!G16%*
M(P&10P``/4#OS6%*JXF10P`$/4"8NF%*W/Z10P`(/4`0,F%*5':10P`,/4##
MTF%*X?"10P`0.4```)%#`!210P`8D4,`7(`!`"2#P0`8."$`('P(`Z9.@``@
ME"'_T'P(`J94J1@X0I\`!;]!`!A_R`*F?'T;>)`!`#0_W@`"?)PC>#O>/X1\
MORMX@4,`%'TI4A1\"DA`0($`$(%#`!@Y2@`!D4,`&(!]`%Q7ZA]^.UT`')$]
M`!2!/0`8+`,``'TI4A21/0`80:(`3"$C`$!_^_MX?!](`$"!``A].TMX?V7;
M>'^$XWA\>AH42``-58$]`%Q].TH4+`D`0)$]`%Q`H@`T?Z/K>'_[^%!_G-H4
M2__AI7^<^A0L'P`_?)_@4$&A`!Q_Y?MX?T/3>$@`#163_0!<.6$`,$@`#%@X
MH`!`?T/3>#O__\!(``SY?Z/K>$O_X65+___$E"'_T'P(`J9"GP`%.4#_@+]!
M`!A_R`*F.X0`')`!`#0_W@`"?'T;>#O>/HQ\GR-X@V0`%(-$`!A7:>Z^.*D`
M`7U<2:XL!0`X?'PJ%$"!`/P@I0!`.(```$@`#G%_X_MX2__@_3B@`#@X@```
M?X/C>$@`#EF37P!4?^/[>)-_`%A+_^#=B3\``'_C^WB9/0``H3\``)D]``&!
M/P``52G"/ID]``*!/P``F3T``XD_``29/0`$H3\`!)D]``6!/P`$52G"/ID]
M``:!/P`$F3T`!XD_``B9/0`(H3\`")D]``F!/P`(52G"/ID]``J!/P`(F3T`
M"XD_``R9/0`,H3\`#)D]``V!/P`,52G"/ID]``Z!/P`,F3T`#XD_`!"9/0`0
MH3\`$)D]`!&!/P`052G"/ID]`!*!/P`0F3T`$T@`"XTY80`P2``*]""E`#@X
M@```2___(#P`__]\+`MX.2```&``?N!A*8#L?"$!;GP(`J9"GP`%OJS_U'_(
M`J:0#``$/]X``COA@/`[WCTD?'D;>(%"C_A]20DN.4```($^@)"`Z0`$@0D`
M"(%)``R`R0`0D/]_F)$??YR`Z0`4@0D`&)%??Z"!20`<D-]_I)#_?ZB17W^P
MD1]_K($)`""!20`D@QZ`/)$??[217W^X@0D`*'\#PWB!20`L@2D`,)$??XR1
M7W^0D3]_E$S&,8)+_^Y5?'T;>4&"`$")/0``+`D``$&B`#1+__KU?Z/K>$@`
M"JU\?1MX.2```&$I@.Q]20@N@2*/^'U*2GDY(```0:(%1$@`"95+__I].Y]_
MB'Q]&WE!@@%@?Z/K>#N]__](``O]5&,(/#AC``%(``N1?'H;>'Q\&WB,_0`!
M+`<``$"B`4@[GW^@A[P`!"P=``!!@@`\?Z/K>$S&,8)+_^VY?'T;>4&B_^2)
M/0``+`D``$&"_]A+_^Z%+`,``$&"_\Q_H^MX2``*"7Q]&W@[?W^4+!T``$""
M`!R'FP`$+!P``$&"`2B)/```+`D``$"B`/Q_H^MX2``+:7Q[&WA_0]-X2``+
M77][&A0[>P0$?V/;>$@`"NV"_H!(?TK3>($^@)A\?!MX?Z?K>(#>@,`XH/__
M.(```7[HNWA,QC&"2``+43B``<!_@^-X2``+A2P#__]`@@#`2``+B8$#```L
M"``10:(`L($^@,A_A^-X.(```8#9``"`OH#$@&D``$S&,8)(``N].Z```$O_
M_J!,QC&"2__LQ7QI&WE!@@`<B2D``"P)``!!H@`02``))7Q]&WE`HOZHA'P`
M!"P#``!`@O_0@[Z`N$O__I2`WH"\?X/C>#B@__\X@``!.YP``DS&,8)(``JM
M2__^E'^#XWA+_^U-+`,``$&"_N1_@^-X2``(T7Q]&WA+__[,.Z```$O__N0X
MGW\@?X/C>$@`!WU\=AMY08(`*($^@,A_A^-X.(```8#9``"`OH#,@&D``$S&
M,8)(``K]2___0($_?S!5*00F+`E``$""_]"#OW\X2``(X7P=&`!`@O_`@3]_
M,%4I!?XL"0'`0(+_L']CVWA(``F!?'T;>(!^@-!,QC&"2__KR2P#``!`@@&$
M@WD``']CVWA(``F]*`,``WQZ&WA`@0!L@)Z`U#AC__Q\>QH42``'L2P#``!`
M@@!4*!H`!$&"`!1_6](4B3K_^RP)`"]`H@`\@UD`!"P:``!!@@`P?T/3>$@`
M"6TH`P`#0($`((">@-@X8__\?'H:%$@`!V4L`P``0((`"'];TWA+__<]?'H;
M>4""`<A_8]MX.(```$S&,8)(``=-?'L;>4&B`;`XX``".*#__SC`_^X[/W_\
M2``*<3B@``9_),MX?V/;>$@`!S&)/W_\+`D``$""`-")/W_]+`D`0T"B`,2)
M/W_^+`D`04"B`+B)/W__+`D`0T"B`*R)(0#P+`D`2$"B`*")(0#Q+`D`14"B
M`)0XX``".*#__SC`_\9_8]MX2``*!3B@`"E_),MX?V/;>$@`!L6!7H`H?RG+
M>(#>@-Q^Z+MX?X?C>#B@__\X@``!?Z/K>$S&,8)(``B=?X/C>$@`!L5_`\-X
M?Z3K>$S&,8)+_^WE?Z/K>$O_]OU+__P4@WD``$@`!K%\9!MX?V/;>$O_\45\
M>QMY0(+^;$O__F0XX```.*```#C```!_8]MX.J```#K??_Q(``EM8K6``$O_
M^!E\>1MX?J6K>'[$LWA_8]MX2``&(7QE&WE!H0!D?V/;>#M_?^A(``F=?R3+
M>']CVWA+__EI@MZ`O#L_?[Q\^]"N?R/+>'[&LW@XH/__.(```3M:``$[.0`"
M3,8Q@D@`!]4L&@`40(+_V#D@``"!7H`HF3]_Y#D_?[Q+__\`?L2S>'\CRWA+
M__@92___?(">@(R`?H!H3,8Q@DO_[/E(``;5@_Z`*'[HNWB`WH#@?&D;>'^'
MXW@XH/__.(```7^CZWA_ZOMX3,8Q@D@`!VDX@`'`?Z/K>$@`!YTL`___0*+^
MO$@`!Z&!(P``+`D`$4"B_JQ(``:!D^$`"#K6``&`WH#D?&D;>'[*LWA^Z+MX
M?X?C>#B@__\X@``!?Z/K>$S&,8)(``<12___J(%A``!_H^MX2``$C)0A_\!\
M"`*F0I\`!;[A`!Q_R`*F/]X``I`!`$0[WC;P@_Z`%(!_``!(``A%?'T;>(!_
M``!(``@YB3T`9)DC`&6`?H!@3,8Q@DO_Z'TL`P``08(`'(DC```L"0`Q0*(`
M$(DC``$L"0``08(`"$O_\KF`?P``2``'^8">@.@XP``+.*```4@`!?F#OH`8
M+`,``$"B`.B`?P``2``'U8">@.PXP``#.*```4@`!=5\?!MY0((!I(!_``!(
M``>U@)Z`]#C```,XH``!2``%M7Q\&WE!@@`P@'Z`0$S&,8)+_^?I?'L;>8!_
M``!!@@&P2``'@8$\``Q_9=MX@(D``$@`!/&`?P``2``':7Q\&WB`?P``2``'
M78">@/@XH``!2``%T8"^@/Q\9!MX?X/C>$@`!,&`?P``2``'.3D@``"9(P!E
M@'Z`/$S&,8)+_^=]+`,``)!]$!!`H@%@@'T0"$O_^%TL`P``D'T0$$"B`4R`
M?H$`3,8Q@D@`!9F!(P`,/P``(#N```%C&`0`@TD`&($]$`P[//__@'\``'P)
MX`!`@0`@2``&S3C```!_)<MX?T33>$@`!DU\>QMY0*(`'($]$`PY*?__?!E(
M`$""_LP[@``!2```<(%=$`A7B1`Z?NI(+H%;``"!*@`(?PE(."P)!`!`@@`@
M@(H`#'[CNWA(``+A+`,``$"B_[@[G``!2___@(!_``!(``99@)L``#C```(X
MH```2``#V7QD&WA+___,2``&/7]$TW@[G``!2``#(8$]$`R`?P``?`G@`$&!
M_^1+__Y$@'\``$@`!A6!/``,@+Z`\(")``!(``.%@3P`#($I``"!*0`(=2D`
M0$&"_CB`?P``2``%Z8$\``R`B0``2``$[4O__B!(``75@5T0"($\``R`B@``
M@&D``$O_Z-%+__Y0@_T0$#B``<!_X_MX2``$?2P#`!%\9AMX08(`*#DC``$H
M"0`!0*$`'($]$`A_Y?MX@'Z!!(")``!,QC&"2``$'3EA`$!(``&8E"'_T'P(
M`J9"GP`%OR$`%'_(`J9\?!MX/]X``I`!`#1\FR-X.]XT_'RZ*W@[H```2__3
M!8,^@`2#_H``?_GX4'__%G!\'?A`0*(`##EA`#!(``%,5ZD0.G]%TWA_9-MX
M?3E(+G^#XW@[O0`!?2D#IDZ`!"%+___0E"'_\#@A`!!.@``@E"'_X'P(`J9"
MGP`%D\$`&'_(`J8_W@`"D`$`)#O>-("!/H``@,D``$@``H6``0`D@\$`&#@A
M`"!\"`.F3H``()0A_^!\"`*F0I\`!7R%(WA\9!MX.&```Y/!`!A_R`*F/]X`
M`I`!`"0[WC1$2``$<8`!`"2#P0`8."$`('P(`Z9.@``@E"'_X'P(`J9"GP`%
M?(4C>'QD&W@X8``#D\$`&'_(`J8_W@`"D`$`)#O>-`!(``1-@`$`)(/!`!@X
M(0`@?`@#IDZ``""4(?_@?`@"ID*?``63P0`8?\@"IC_>``*0`0`D.]XSO$@`
M`36!R_^X@>O_O((+_\""*__$@DO_R()K_\R"B__0@JO_U(++_]B"Z__<@PO_
MX(,K_^2#2__H@VO_[(.+__"#J__T@\O_^(`+``2#Z__\?`@#IGUA6WA.@``@
M8````&````"!?H)$?6D#IDZ`!"!@````@7Z"2'UI`Z9.@`0@8````(%^@DQ]
M:0.F3H`$(&````"!?H)0?6D#IDZ`!"!@````@7Z"5'UI`Z9.@`0@8````(%^
M@EA]:0.F3H`$(&````"!?H)<?6D#IDZ`!"!@````@7Z"8'UI`Z9.@`0@8```
M`(%^@F1]:0.F3H`$(&````"!?H)H?6D#IDZ`!"!@````@7Z";'UI`Z9.@`0@
M8````(%^@G!]:0.F3H`$(&````"!?H)T?6D#IDZ`!"!@````@7Z!9'UI`Z9.
M@`0@8````(%^@GQ]:0.F3H`$(&````"!?H*`?6D#IDZ`!"!@````@7Z"A'UI
M`Z9.@`0@8````(%^@HA]:0.F3H`$(&````"!?H*,?6D#IDZ`!"!@````@7Z"
MD'UI`Z9.@`0@8````(%^@K!]:0.F3H`$(&````"!?H*8?6D#IDZ`!"!@````
M@7Z!C'UI`Z9.@`0@8````(%^@J!]:0.F3H`$(&````"!?H*D?6D#IDZ`!"!@
M````@7Z"J'UI`Z9.@`0@8````(%^@JQ]:0.F3H`$(&````"!?H*P?6D#IDZ`
M!"!@````@7X`?'UI`Z9.@`0@8````(%^@KA]:0.F3H`$(&````"!?H*\?6D#
MIDZ`!"!@````@7Z"P'UI`Z9.@`0@8````(%^@L1]:0.F3H`$(&````"!?@"0
M?6D#IDZ`!"!@````@7Z"S'UI`Z9.@`0@8````(%^@M!]:0.F3H`$(&````"!
M?H+4?6D#IDZ`!"!@````@7Z"V'UI`Z9.@`0@8````(%^@MQ]:0.F3H`$(&``
M``"!?H+@?6D#IDZ`!"!@````@7Z"Y'UI`Z9.@`0@8````(%^@NA]:0.F3H`$
M(&````"!?H+L?6D#IDZ`!"!@````@7Z"\'UI`Z9.@`0@8````(%^@O1]:0.F
M3H`$(&````"!?H+X?6D#IDZ`!"!@````@7Z"_'UI`Z9.@`0@8````(%^@P!]
M:0.F3H`$(&````"!?H,$?6D#IDZ`!"!@````@7Z#"'UI`Z9.@`0@8````(%^
M@PQ]:0.F3H`$(&````"!?H,0?6D#IDZ`!"!@````@7Z#%'UI`Z9.@`0@8```
M`(%^@QA]:0.F3H`$(&````"!?H,<?6D#IDZ`!"!@````@7Z#('UI`Z9.@`0@
M8````(%^@R1]:0.F3H`$(&````"!?H(4?6D#IDZ`!"!@````@7Z#+'UI`Z9.
M@`0@8````(%^@AQ]:0.F3H`$(&````"!?H,T?6D#IDZ`!"!@````@7Z#.'UI
M`Z9.@`0@8````(%^@SQ]:0.F3H`$(&````!(``$`2```_$@``/A(``#T2```
M\$@``.Q(``#H2```Y$@``.!(``#<2```V$@``-1(``#02```S$@``,A(``#$
M2```P$@``+Q(``"X2```M$@``+!(``"L2```J$@``*1(``"@2```G$@``)A(
M``"42```D$@``(Q(``"(2```A$@``(!(``!\2```>$@``'1(``!P2```;$@`
M`&A(``!D2```8$@``%Q(``!82```5$@``%!(``!,2```2$@``$1(``!`2```
M/$@``#A(```T2```,$@``"Q(```H2```)&````!@````8````&````!@````
M8````&````!@````/6L``'P(`J9"GP`%.6L!#'V(`J9\"`.F?6Q84#V,``*`
M#*]P@8RO='P)`Z9\"UH4?6!:%$Z`!"!@````8````)0A__!\"`*FD`$`%)/!
M``A"GP`%?\@"IH`!`!1\"`.F@\$`"#@A`!!.@``@``(``2XN`"5S+R5S`"]P
M<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E
M<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E<P!005)?5$5-4`!005)?4%)/
M1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!
M4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'
M`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2
M`%!!4E]435!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`
M4$%27T-,14%./0`Q`$Q$7TQ)0E)!4EE?4$%42`!P87(M`"UE`"TM`%-94U1%
M30`O=&UP`%1%35!$25(`5$U0`%5315(`55-%4DY!344`)3`R>``E<R5S)7,E
M<P`E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*`"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I
M<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E
M<F%T:6]N*0H`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U
M)7,`)7,E<W1E;7`M)74M)74E<P!!4D=6`!@`<&5R;`!005(Z.E!A8VME<CHZ
M5D524TE/3@`Q+C`U,`!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R
M>0`E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R
M;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R
M('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L
M("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S
M*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I
M;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]
M+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E
M;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z
M.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*
M54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H
M:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@
M6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*
M>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@
M+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@
M)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@
M)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N
M9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N
M86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF
M(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PHD4$%27TU!1TE#(#T@
M(EQN4$%2+G!M7&XB.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I
M970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E
M<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@
M("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N
M97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3
M,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A
M<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L
M("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O
M9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ
M92`]("US("1P<F]G;F%M93L*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0[
M"FUY("1M86=I8U]P;W,["FEF("@D<VEZ92`\/2`D8VAU;FM?<VEZ92D@>PHD
M;6%G:6-?<&]S(#T@,#L*?2!E;'-I9B`H*&UY("1M(#T@)'-I>F4@)2`D8VAU
M;FM?<VEZ92D@/B`P*2!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1M.PI](&5L
M<V4@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D8VAU;FM?<VEZ93L*?0IW:&EL
M92`H)&UA9VEC7W!O<R`^/2`P*2!["G-E96LH7T9(+"`D;6%G:6-?<&]S+"`P
M*3L*<F5A9"A?1D@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?
M34%'24,I*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#
M*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M86=I8U]P
M;W,@+3T@)&-H=6YK7W-I>F4["GT*;&%S="!I9B`D;6%G:6-?<&]S(#P@,#L*
M<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").(BP@)&)U
M9BDL(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T
M.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,
M12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5
M;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D
M9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F
M.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H
M+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D
M97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@
M/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L
M<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D
M8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL
M96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@
M/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F
M(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*
M?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY
M("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE
M(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`](&1E;&5T92`D<F5Q=6ER95]L:7-T
M>R1M;V1U;&5](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R
M+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I
M;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D
M:6YF;RT^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE
M;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D:6YF;RT^>V-R8WTN
M<&TB+"`D:6YF;RT^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA
M;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E
M*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE
M9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM
M>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2![
M"G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$
M4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER
M92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I
M;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R
M97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q
M(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@
M("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*
M;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE
M=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y
M(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.
M5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q
M("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@
M<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS
M=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`
M05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6
M.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![
M(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL
M92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI
M*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?
M:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B([
M"GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q
M(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G
M0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*
M)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H
M+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2([
M"GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H
M:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E
M;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*
M?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*
M>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q
M=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM
M>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/"<L
M("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D
M92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D
M("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP
M(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2![
M"B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M
M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L
M("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@
M)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P
M87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S
M7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE
M+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ
M3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@
M9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S
M*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L
M;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA
M<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K
M97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A
M;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`]
M(")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")0
M05)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I
M8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@
M;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O
M(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR
M97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@
M?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1?
M?2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E
M<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT
M?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*
M;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII
M9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL
M92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI
M*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE
M;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY
M("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D
M:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL
M87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@
M)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A0
M86-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L
M"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G
M/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM
M;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D
M960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@
M/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO
M=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%
M(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D[
M"B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z
M.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT
M*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O
M;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D
M>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`[
M"FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I
M*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM
M>2`D9F@L("(\(BP@)&]U="D["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL
M92@D9F@I.PIC;&]S92@D9F@I.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I
M9V5S=#L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C
M86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN
M="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L
M;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*"1005)?34%'24,I
M.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S
M="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D[
M"G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA
M;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A
M.B`D0"(["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY
M("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"D@;W(@9&EE("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2
M.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@
M<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB
M97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER
M96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*
M;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE
M(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%
M3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA
M;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*
M;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E
M861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ
M<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI
M.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H
M;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]
M"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\
M/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;
M("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP
M;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM0
M05)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD[
M"GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]
M($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*
M<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I
M('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]
M"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$
M>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR
M97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*
M<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N
M=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ
M2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:
M;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(
M03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!0
M05(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB
M=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I
M;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@
M<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I
M<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@
M4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U
M:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I
M('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H
M("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$
M25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P
M871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@
M/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H
M)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO
M9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE
M(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%
M?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S
M+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP
M87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R
M;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B
M=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X
M+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]
M"F5L<V4@>PIM>2`D9&EG97-T(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI3
M2$$["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N*&UY("1F
M:"P@(CPB+"`D<')O9VYA;64I.PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG97-T.PI]('Q\("1M
M=&EM93L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21D:6=E
M<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`]
M(#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD
M14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@
M>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL
M;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M
M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D
M9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N
M86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC
M;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D
M;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH
M)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R
M;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D
M14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q
M.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@
M:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O
M9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D
M0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-
M17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I
M('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@
M:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I
M('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O
M<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L
M("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@
M86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF
M:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH
M*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL
M(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*
M?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%
M3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C
M=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W
M9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD
M<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D
M<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])
M3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[
M4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0
M($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6
M>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"
M54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P
M87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B
M.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.
M?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2![
M"FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B
M0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O
M7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D
M<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE
M;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER
M92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I
M9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E
M87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP
M"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#
M+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I
M92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M
M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P
M<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z
M.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ
M7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T52
M4D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*`````'!E<FQX<VDN8P!?
M7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(````1L#.P```1@````B
M__^.^```!0C__Y(\```!3/__H'P```&,__^A0````<3__Z&,```!Y/__HB0`
M``(0__^BO````CC__Z/X```";/__I-@```*@__^FO````MS__Z<,```#!/__
MIV0```,L__^H(````US__ZA8```#A/__JB0```/,__^J5````^C__ZN@```$
M$/__K4````1`__^ML```!&C__ZWX```$D/__KM````30__^O7```!3C__Z_D
M```%8/__L.````64__^R-```!<S__[A\```&%/__NW@```90__^[\```!HC_
M_[O\```&H/__O#P```;(__^\@```!O#__[S$```'&/__O.@```=X__^]2```
M`3`````0``````%Z4@`$?$$!&PP!`````!@````8__^\$```!3```P$^"4$`
M1`9!```````\````-/__D.@```Y``$$.D`-!"4$`1)<)F`B9!YH&FP6<!)T#
MG@*?`48107\#`X3?WMW<V]K9V-<&00``````-````'3__Y[H````Q`!!#C!!
M"4$`0ID'F@:;!9P$G0.>`I\!1A%!?TL*W][=W-O:V09!"P`````<````K/__
MGW0```!,`$$.($(107].#@!!!D$``````"@```#,__^?H````)@`00XP00E!
M`$*=`YX"GP%&$4%_7-_>W09!````````)````/C__Z`,````F`!!#I`!00E!
M`$*>`I\!1A%!?US?W@9!`````#````$@__^@?````3P`00Z@`4$)00!"F@:;
M!9P$G0.>`I\!11%!?P)&W][=W-O:!D$````P```!5/__H80```#@`$$.P"!!
M"4$`0YH&FP6<!)T#G@*?`48107]MW][=W-O:!D$`````.````8C__Z(P```!
MY`!!#E!!"4$`0I<)F`B9!YH&FP6<!)T#G@*?`48107\";]_>W=S;VMG8UP9!
M````)````<3__Z/8````4`!!#B!!"4$`0IX"1!%!?TK>#@!!!D$``````"0`
M``'L__^D`````%@`00X@00E!`$*>`I\!1!%!?T[?W@9!```````L```"%/__
MI#````"\`$$.L$!!"4$`0IP$G0.>`I\!1A%!?V7?WMW<!D$````````D```"
M1/__I+P````X`$$.($$)00!"G@)$$4%_1-X.`$$&00``````1````FS__Z3,
M```!S`!!#K`A00E!`$.6"I<)F`B9!YH&FP6<!)T#G@*?`4<107\%1@L"9]_>
MW=S;VMG8U]8&009&````````&````K3__Z90````,`!!#A!%"@X`00L`````
M`"0```+0__^F9````4P`00X@00E!`$*>`I\!11%!?T@*W]X&00L````L```"
M^/__IX@```&@`$$.8$$)00!#FP6<!)T#G@*?`44107\"7M_>W=S;!D$````D
M```#*/__J/@```!P`$$.($$)00!"G@*?`40107]4W]X&00``````)````U#_
M_ZE`````2`!!#B!!"4$`0IX"1!%!?TC>#@!!!D$``````#P```-X__^I8```
M`-@`00XP00E!`$*;!9P$G0.>`I\!11%!?U`*!D%#W][=W-L.`$(+6-_>W=S;
M!D$````````T```#N/__J?@```",`$$.($$)00!"G0.>`I\!11%!?U8*!D%!
MW][=#@!!"T+?WMT&00```````"P```/P__^)Z````>``00XP00E!`$*<!)T#
MG@*?`4H107\"90K?WMW<!D$+`````"0```0@__^J'````(@`00X@00E!`$.>
M`D0107]7W@X`009!```````P```$2/__JGP```#\`$$.,$()00!"F@:;!9P$
MG0.>`I\!1A%!?VT*W][=W-O:!D$+````-```!'S__ZM$```!5`!!#C!!"4$`
M0YH&FP6<!)T#G@*?`48107\"1PK?WMW<V]H&00L```````!$```$M/__K&``
M``9(`$8.H(("00E!`$*5"Y8*EPF8")D'F@:;!9P$G0.>`I\!11%!?P,!A-_>
MW=S;VMG8U];5!D$````````X```$_/__LF````+\`$$.0$$)00!"EPF8")D'
MF@:;!9P$G0.>`I\!1!%!?P*WW][=W-O:V=C7!D$````T```%./__M2````!X
M`$$.,$$)00!"F0>:!IL%G`2=`YX"GP%&$4%_2PK?WMW<V]K9!D$+`````!0`
M``5P__^U8`````P`00X000X``````"0```6(__^U5````$``00X@00E!`$*>
M`D0107]&W@X`009!```````D```%L/__M6P```!$`$$.($$)00!%G@)$$4%_
M1-X.`$$&00``````)```!=C__[6(````1`!!#B!!"4$`19X"1!%!?T3>#@!!
M!D$``````!P```8`__^UI````"0`00X@00E!`$*>`D0107\`````/``````!
M>E(`!'Q!`1L,`0`-"Q%!?XX2CQ&0$)$/D@Z3#90,E0N6"I<)F`B9!YH&FP6<
M!)T#G@*?`0```````#@```!$__^U:````%@`0<Y!ST'00=%!TD'30=1!U4'6
M0==!V$'90=I!VT'<0=U!WD+?009!00T!````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````0```TT````!```#6`````$```-H````#P``!/<````,```;]`````T`
M`$_`````&0`!_)P````;````!````!H``?R@````'`````0````$```!J&__
M_O4```90````!0``#A0````&```'I`````H```45````"P```!`````5````
M``````,``?\$`````@```O0````4````!P```!<``!D`````!P``%)@````(
M```'7`````D````,<``````!_O@````8`````&____L(```!;____@``$_AO
M____`````F____```!,J;___^0```%,`````````````````````````````
M```````````````````````````````!_=0`````````````3H```$Z$``!.
MB```3HP``$Z0``!.E```3I@``$Z<``!.H```3J0``$ZH``!.K```3K```$ZT
M``!.N```3KP``$[```!.Q```3L@``$[,``!.T```3M0``$[8``!.W```3N``
M`$[D``!.Z```3NP``$[P``!.]```3O@``$[\``!/````3P0``$\(``!/#```
M3Q```$\4``!/&```3QP``$\@``!/)```3R@``$\L``!/,```3S0``$\X``!/
M/```3T```$]$``!/2```3TP``$]0``!/5```3U@``$]<``!/8```3V0``$]H
M``!/;```3W```$]T``!/>````````````````````````````````/____\`
M````````````````````````````````````````````````````````````
M````````1T-#.B`H1TY5*2`Q,"XS+C$@,C`R,3`U,3`@*$%/4T,@3U,L($-O
M<F4I```N<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N8G5I;&0M:60`+FYO
M=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R
M<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET
M`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`
M+FEN:71?87)R87D`+F9I;FE?87)R87D`+F=O=#(`+F1Y;F%M:6,`+F=O=``N
M9&%T80`N<V1A=&$`+F)S<P`N8V]M;65N=```````````````````````````
M```````````````````````````````````+`````0````(```%4```!5```
M``T```````````````$`````````$P````<````"```!9````60````D````
M```````````$`````````"8````'`````@```8@```&(````(```````````
M````!``````````X````!0````(```&H```!J```!*@````&``````````0`
M```$````-&____8````"```&4```!E````%4````!@`````````$````!```
M`#X````+`````@``!Z0```>D```&<`````<````"````!````!````!&````
M`P````(```X4```.%```!14```````````````$`````````3F____\````"
M```3*@``$RH```#.````!@`````````"`````@```%MO___^`````@``$_@`
M`!/X````H`````<````"````!`````````!J````!`````(``!28```4F```
M!&@````&``````````0````,````=`````0```!"```9````&0````+T````
M!@```!<````$````#````'X````!````!@``&_0``!OT````1```````````
M````!`````````"$`````0````8``!Q````<0```,X```````````````!``
M````````B@````$````&``!/P```3\`````L```````````````$````````
M`)`````!`````@``3^P``$_L```]7```````````````!`````````"8````
M`0````(``(U(``"-2````1P```````````````0`````````I@````$````"
M``".9```CF0```:<```````````````$`````````+`````.`````P`!_)P`
M`/R<````!```````````````!`````0```"\````#P````,``?R@``#\H```
M``0```````````````0````$````R`````$````#``'\I```_*0```$P````
M```````````$`````````,X````&`````P`!_=0``/W4```!(`````<`````
M````!`````@```#7`````0````,``?[T``#^]````!````````````````0`
M```$````>0````$````#``'_!```_P0```#\```````````````$````````
M`-P````!`````P`"`````0``````3```````````````!`````````#B````
M`0````,``@!,``$`3`````0```````````````0`````````Z0````@````#
M``(`4``!`%```!`8```````````````$`````````.X````!````,```````
M`0!0````*P```````````````0````$````!`````P````````````$`>P``
2`/<```````````````$`````
